"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.genDemoFiles = void 0;
const fs_extra_1 = __importDefault(require("fs-extra"));
const comment_parser_1 = require("comment-parser");
const parser_1 = require("@babel/parser");
const node_path_1 = __importDefault(require("node:path"));
function getMaterialData(content) {
    var _a;
    const blocks = (0, comment_parser_1.parse)(content);
    const baseNode = (0, parser_1.parse)(content, {
        sourceType: 'module',
    });
    const materialData = [];
    for (const block of blocks) {
        const data = {
            kind: 'member',
        };
        for (const tag of block.tags) {
            if (tag.tag === 'file') {
                data.kind = 'file';
            }
            else {
                data[tag.tag] = tag.name;
            }
        }
        materialData.push(data);
    }
    const imports = [];
    for (const node of baseNode.program.body) {
        if (node.type === 'ImportDeclaration' && ((_a = node.source) === null || _a === void 0 ? void 0 : _a.value)) {
            imports.push(node.source.value);
        }
    }
    return { materialData, imports };
}
const getMaterialMdContent = (materialData) => {
    return `\`\`\`json type=description\n${JSON.stringify(materialData, null, 2)}\n\`\`\`\n`;
};
function getDemoMdContent(filename) {
    return __awaiter(this, void 0, void 0, function* () {
        // 获取文件类型
        const fileExt = node_path_1.default.extname(filename).slice(1);
        const code = yield fs_extra_1.default.readFile(filename, 'utf8');
        return `::: raw \n\n:::demo\n\n\`\`\`${fileExt}\n${code}\n\`\`\`\n\n:::\n\n:::`;
    });
}
const genDemoFiles = (file, outDir) => __awaiter(void 0, void 0, void 0, function* () {
    var _a;
    try {
        const demoDirname = node_path_1.default.dirname(file);
        const indexContent = yield fs_extra_1.default.readFile(file, 'utf8');
        const { materialData, imports } = getMaterialData(indexContent);
        const demoDecArr = materialData.filter(d => d.kind === 'member');
        let index = 0;
        const demoFileNames = [];
        for (const item of imports) {
            const filename = node_path_1.default.resolve(demoDirname, item);
            let fileName = node_path_1.default.basename(filename).split('.');
            let content = yield getDemoMdContent(filename);
            if (demoDecArr[index]) {
                content = `## ${demoDecArr[index].title}\n\n${demoDecArr[index].description}\n\n${content}`;
            }
            // console.log('content', content)
            // fs.writeFileSync
            demoFileNames.push(`${fileName[0]}.md`);
            const outputPath = node_path_1.default.join(outDir, `${fileName[0]}.md`);
            yield fs_extra_1.default.outputFile(outputPath, content);
            index++;
        }
        // 生成 index.md
        const fileDec = (_a = materialData.filter(d => d.kind === 'file')) === null || _a === void 0 ? void 0 : _a[0];
        const componentName = fileDec.title || '组件名';
        const componentDesc = fileDec.description || '组件描述';
        let fileContent = `# ${componentName}\n\n${componentDesc}`;
        for (const demoFileName of demoFileNames) {
            fileContent = `${fileContent}\n\n<!--@include: ./${demoFileName} -->`;
        }
        // 增加 API
        fileContent = `${fileContent}\n\n<!--@include: ./API.md -->`;
        yield fs_extra_1.default.outputFile(node_path_1.default.join(outDir, `index.md`), fileContent);
    }
    catch (error) {
    }
});
exports.genDemoFiles = genDemoFiles;
function parseMaterial(content, { matcher, dirname }) {
    return __awaiter(this, void 0, void 0, function* () {
        const match = content.match(matcher);
        if (match && match[1]) {
            const filename = node_path_1.default.resolve(dirname, match[1]);
            const demoDirname = node_path_1.default.dirname(filename);
            const indexContent = yield fs_extra_1.default.readFile(filename, 'utf8');
            const { materialData, imports } = getMaterialData(indexContent);
            let result = `${getMaterialMdContent(materialData)}\n`;
            for (const item of imports) {
                const filename = node_path_1.default.resolve(demoDirname, item);
                result += `${yield getDemoMdContent(filename)}\n`;
            }
            return content.replace(match[0], result);
        }
        return content;
    });
}
exports.default = parseMaterial;
//# sourceMappingURL=parse-material.js.map