"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../utils");
const bindingsTmpl = (bindings) => {
    return (bindings || [])
        .map((binding) => {
        const { type, name, description } = binding;
        const res = [];
        name && res.push(name);
        if (type === null || type === void 0 ? void 0 : type.name) {
            res.length && res.push(': ');
            res.push(`\`${type.name}\``);
        }
        description && res.push(description);
        return res.join('');
    })
        .join('\n');
};
const tmpl = (slots, lang) => {
    const displayableSlots = slots.filter((slot) => { var _a; return slot.description || lang in ((_a = slot.tags) !== null && _a !== void 0 ? _a : {}); });
    const hasVersion = displayableSlots.some((slot) => { var _a; return (_a = slot === null || slot === void 0 ? void 0 : slot.tags) === null || _a === void 0 ? void 0 : _a.version; });
    const content = displayableSlots
        .map((slot) => {
        var _a;
        const { name, bindings, tags } = slot;
        let { description } = slot;
        if (tags === null || tags === void 0 ? void 0 : tags[lang]) {
            description = tags[lang].content;
        }
        let lineContent = `|${(0, utils_1.toKebabCase)(name)}|${(0, utils_1.escapeCharacter)(description || '')}|${(0, utils_1.escapeCharacter)(bindingsTmpl(bindings)) || '-'}|`;
        if (hasVersion) {
            const version = (_a = tags === null || tags === void 0 ? void 0 : tags.version) === null || _a === void 0 ? void 0 : _a.content;
            lineContent += `${version || ''}|`;
        }
        return lineContent;
    })
        .join('\n');
    return {
        hasVersion,
        content,
    };
};
exports.default = (slots, lang) => {
    const { content, hasVersion } = tmpl(slots, lang);
    if (!content)
        return '';
    const header = lang === 'en'
        ? ['|Slot Name|Description|Parameters|', '|---|---|---|']
        : ['|插槽名|描述|参数|', '|---|:---:|---|'];
    if (hasVersion) {
        header[0] += lang === 'en' ? 'version|' : '版本|';
        header[1] += ':---|';
    }
    return `
${header[0]}
${header[1]}
${content}
`;
};
//# sourceMappingURL=slots.js.map